:mod:`!ns` -- Package containing namespaces
===========================================

.. automodule:: ll.xist.ns

.. toctree::
   :maxdepth: 2
   :caption: Package content
   :name: xist_ns_content

   XIST_ns_html
   XIST_ns_xml
   XIST_ns_ihtml
   XIST_ns_docbook
   XIST_ns_svg
   XIST_ns_abbr
   XIST_ns_code
   XIST_ns_form
   XIST_ns_php
   XIST_ns_jsp
   XIST_ns_meta
   XIST_ns_ruby
   XIST_ns_specials
   XIST_ns_htmlspecials
   XIST_ns_doc
   XIST_ns_kid
   XIST_ns_detox
   XIST_ns_toxic
   XIST_ns_rng
   XIST_ns_rss091
   XIST_ns_rss20
   XIST_ns_atom
   XIST_ns_strutshtml
   XIST_ns_strutsconfig
